/************** BEST VIEWED IN A CODE EDITOR 80 COLUMNS WIDE *******************
*
* Dewalt Toughcase+ Clip
* Benjamen Johnson <3dprints.electronsmith.com>
* 20201108
*
* openSCAD Version: 2019.05 
* Licesnse: Creative Commons - Attribution - Share Alike
*           https://creativecommons.org/licenses/by-sa/4.0/
*******************************************************************************/
// Todo
// adjust bar size in edit me

/*[Hidden]*/
version="V1.0";

// add a little bit to cuts to make them render properly
$dl = 0.01;

/*[Bar Parameters]*/
/*******************************************************************************
*
*       -  ---
*      | |  |
*      | |  |
*      | |   bar_width
*      | |  |
*      | |  |
*       -  ---
*       |
*        bar_thickness
*******************************************************************************/
//width of the bar
bar_width = 51.3;

// thickness of the bar
bar_thickness = 3.6;

/*[Tab Parameters]*/
/*******************************************************************************
* the holder is defined by the dimensions of the bar and the wall thickness
*******************************************************************************/
// Wall thickness of the slider
wall_thickness = 3;

// How tall the sliding part of the holder is
slider_depth = 20;

// How wide the clp that hold the box is
tab_width = 46;

// How high the tab sits above the bar
tab_height = 2.5;

// how deep the tab fits into the box
tab_depth = 5;

//how thick the tab is (strength)
tab_thickness = 4;

slider_width = bar_width+2*wall_thickness;
slider_thickness = bar_thickness +2*wall_thickness;

/*[Stamp Options]*/
/*******************************************************************************
* Stamp Options
*******************************************************************************/
// Which font do you want to use
font = "REGISTRATION PLATE UK:style=Bold";

// How big you want the text
font_size = 10;//[0:0.5:8]

// How thick the font is (back to front)
font_thickness = 0.6;

/*******************************************************************************
* Make it
*******************************************************************************/
//translate([0,0,slider_depth/2])
difference(){
    make_clip();
    
    translate([0,-bar_thickness/2-wall_thickness+font_thickness,0])
        rotate([90,0,0])
        stamp_version(version, font_size, font_thickness);
}// end difference

/*******************************************************************************
* Module for making the dewalt Toughcase clip
*******************************************************************************/
module make_clip(){
    
HOLDER_DEF=[slider_width,slider_thickness, slider_depth]; 
BAR_CUT = [bar_width,bar_thickness, slider_depth+$dl];
    
    difference(){
        union(){
            difference(){
                // make body
                cube(HOLDER_DEF,center = true);
                
                //make cut for bar
                cube(BAR_CUT,center=true);
            
            } //end difference
            
            // make tab
            translate([0,(bar_thickness+tab_thickness)/2+tab_height,tab_depth/2])
            cube([tab_width,tab_thickness,tab_depth+slider_depth],center = true);
            
            // reinforce pull pin
            cyl_thickness = 10;
            translate([0,(bar_thickness+cyl_thickness)/2 ,0])
            rotate([90,0,0])
            cylinder(r=10,h=cyl_thickness,center = true,$fn=50);
        } //end union
    // cut out the nut
    translate([0,(bar_thickness+6-$dl)/2 ,0])
    rotate([90,0,0])
    cylinder(d=12.7, h=6,center=true,$fn=6);
    
    cyl_thickness = 10;
    //hole
    translate([0,(bar_thickness+cyl_thickness)/2 ,0])
    rotate([90,0,0])
    cylinder(d=7, h=cyl_thickness+$dl,center=true,$fn=50);
    
    // make nut fit
    translate([0,bar_thickness/2+1.5-$dl,-slider_depth/2+5-$dl])
    cube([13,3,10],center=true);
    
    // chamfer the hole for the bar
    chamfer = 1.5;
    scale_x = (bar_width+chamfer)/bar_width;
    scale_y = (bar_thickness+chamfer)/bar_thickness;
    SCALE = [scale_x,scale_y];    
    translate([0,0,slider_depth/2-chamfer+$dl])    
    linear_extrude(height = chamfer,convexity=10,scale=SCALE)    
    square([bar_width,bar_thickness],center=true);

    translate([0,0,-slider_depth/2+chamfer-$dl])    
    rotate([180,0,0])
    linear_extrude(height = chamfer,convexity=10,scale=SCALE)    
    square([bar_width,bar_thickness],center=true);

    }//end difference
} //end module

/*******************************************************************************
* Module for putting the version number on the print
*******************************************************************************/
module stamp_version(version_text,size,thickness){
    color("white")
    linear_extrude(height = thickness)
        text(text = version_text, font = font, size = size, valign="center",halign = "center");
} // end module